@@ -10,6 +10,9 @@
 
 #include <QObject>
 #include <QString>
+#include <QImage>
+
+#include <KActionCollection>
 
 #include <Interface>
 #include <DeviceInformation>
@@ -46,6 +49,11 @@ class Skanpage : public QObject
     Q_PROPERTY(QString deviceModel READ deviceModel NOTIFY deviceInfoUpdated)
     Q_PROPERTY(QString deviceName READ deviceName NOTIFY deviceInfoUpdated)
 
+    Q_PROPERTY(QRectF scanArea READ scanArea WRITE setScanArea NOTIFY scanAreaChanged)
+    Q_PROPERTY(ScanSplit scanSplit READ scanSplit WRITE setScanSplit NOTIFY scanSplitChanged)
+    Q_PROPERTY(QList<QRectF> scanSubAreas READ scanSubAreas NOTIFY scanSubAreasChanged)
+    Q_PROPERTY(QImage previewImage READ previewImage NOTIFY previewImageChanged)
+
 public:
 
     enum ApplicationState {
@@ -55,9 +63,15 @@ public:
         SearchingForDevices,
         NoDeviceOpened
     };
-
     Q_ENUM(ApplicationState);
 
+    enum ScanSplit {
+        ScanNotSplit,
+        ScanIsSplitH,
+        ScanIsSplitV
+    };
+    Q_ENUM(ScanSplit)
+
     explicit Skanpage(const QString &deviceName, QObject *parent = nullptr);
     ~Skanpage();
 
@@ -65,6 +79,13 @@ public:
     QString deviceModel() const;
     QString deviceName() const;
 
+    QRectF scanArea() const;
+    void setScanArea(QRectF area);
+    ScanSplit scanSplit() const;
+    void setScanSplit(ScanSplit split);
+    const QList<QRectF> &scanSubAreas();
+    QImage previewImage() const;
+
     int progress() const;
     int countDown() const;
     ApplicationState applicationState() const;
@@ -78,12 +99,19 @@ public:
     SkanpageConfiguration *configuration() const;
     SkanpageState *stateConfiguration() const;
 
+    Q_INVOKABLE void preview();
     Q_INVOKABLE void startScan();
     Q_INVOKABLE void cancelScan();
     Q_INVOKABLE void reloadDevicesList();
     Q_INVOKABLE bool openDevice(const QString &deviceName, const QString &deviceVendor = QString(), const QString &deviceModel = QString());    
     Q_INVOKABLE bool OCRavailable() const;
     Q_INVOKABLE void print();
+    Q_INVOKABLE void registerAction(QObject* item, QObject* shortcuts, const QString &iconText);
+    Q_INVOKABLE void showShortcutsDialog();
+    Q_INVOKABLE void clearSubAreas();
+    Q_INVOKABLE void eraseSubArea(int index);
+    Q_INVOKABLE bool appendSubArea(QRectF area);
+    Q_INVOKABLE void selectSubArea(int index);
 
 Q_SIGNALS:
     void progressChanged(int progress);
@@ -91,6 +119,10 @@ Q_SIGNALS:
     void optionsChanged();
     void applicationStateChanged(ApplicationState state);
     void deviceInfoUpdated();
+    void scanAreaChanged(const QRectF &area);
+    void scanSplitChanged(ScanSplit split);
+    void scanSubAreasChanged(const QList<QRectF> &subAreas);
+    void previewImageChanged(const QImage& preview);
     void newUserMessage(const QVariant &level, const QVariant &message);
 
 private Q_SLOTS:
@@ -109,6 +141,8 @@ private:
     void loadScannerOptions();
     void saveScannerOptions();
     void checkFinish();
+    void finishPreview();
+    void setupScanningBounds();
     void signalErrorMessage(const QString &text);
 
     std::unique_ptr<SkanpagePrivate> d;
